@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use utf8; # filenames can be in utf8
 
@@ -334,7 +334,7 @@ sub	input_images {
 		if( ! -e $m ){ print STDERR "${whoami} (via $parent), line ".__LINE__." : warning/3, input image '$m' does not exist on disk and will be ignored.\n"; }
 		else { push @{$self->{'input-images'}}, Encode::decode_utf8(Cwd::abs_path($m)) }
 	} else { print STDERR "${whoami} (via $parent), line ".__LINE__." : error, input can be an arrayref of input image filenames, a hashref whose values are filenames or a single filename in the form of a scalar."; return undef }
-	if( $verbos > 1 ){ print STDOUT perl2dump($self->{'input-images'})."${whoami} (via $parent), line ".__LINE__." : called and added some images, above is a list of all input images to make up the animation.\n" }
+	if( $verbos > 1 ){ print STDOUT perl2dump($self->{'input-images'})."${whoami} (via $parent), line ".__LINE__." : called and added some images, above is a list of all input images to create the animation.\n" }
 	return $self->{'input-images'}
 }
 
@@ -350,7 +350,7 @@ Automate::Animate::FFmpeg - Create animation from a sequence of images using FFm
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 
 =head1 SYNOPSIS
@@ -533,30 +533,45 @@ On success, the resultant animation will be
 written to the output file
 (specified using L<output_filename($m)> before the call.
 
-It returns 0 on failure, 1 on success.
+Return value:
+
+=over 4
+
+=item * 0 on failure, 1 on success.
+
+=back
 
 =head2 C<input_images($m)>
 
   my $ret = $aaFF->input_images($m);
 
-Sets or gets the list (as an ARRAYref) of all input images currently in the list
-of images to make up the animation. The optional input parameter, C<$m>,
-is an ARRAYref of input images (their fullpath that is) to make up
+It sets or gets the list (as an ARRAYref) of all input images currently in the list
+of images to create the animation. The optional input parameter, C<$m>,
+is an ARRAYref of input images (their fullpath that is) to create
 the animation.
 
+Return value:
+
+=over 4
+
+=item * the list, as an ARRAYref, of the image filenames currently
+set to create the animation.
+
+=back
+
 =head2 C<input_pattern($m)>
 
   $aaFF->input_pattern($m) or die "failed";
 
 Initiates a search via L<File::Find::Rule> for the
-input image files to make up the animation using
+input image files to create the animation using
 the pattern C<$m-E<gt>[0]> with starting search dir being C<$m-E<gt>[1]>,
 which is optional -- default being C<Cwd::cwd> (current working dir).
 So, C<$m> is an array ref of one or two items. The first is the search
 pattern and the optional second is the search path, defaulting to the current
 working dir.
 
-The pattern (C<$m->[0]>) can be a shell wildcard, e.g. C<*.png>,
+The pattern (C<$m-E<gt>[0]>) can be a shell wildcard, e.g. C<*.png>,
 or a regex specified as C<regex(/REGEX-HERE/modifiers)>, for example
 C<regex(/\.(mp3|ogg)$/i)> Both shell wildcards and regular expressions
 must comply with what L<File::Find::Rule> expects, see [https://metacpan.org/pod/File::Find::Rule#Matching-Rules].
@@ -589,7 +604,13 @@ these orderings for example:
 
 =back
 
-It returns 1 on success or 0 on failure.
+Return value:
+
+=over 4
+
+=item * 0 on failure, 1 on success.
+
+=back
 
 =head2 C<input_patterns($m)>
 
@@ -604,50 +625,84 @@ C<input_patterns()> can be combined with C<input_pattern()>
 and C<input_images()>. The input images list will increase
 in the order they are called.
 
-It returns 1 on success or 0 on failure.
+Return value:
+
+=over 4
+
+=item * 0 on failure, 1 on success.
+
+=back
 
 =head2 C<output_filename($m)>
 
   my $ret = $aaFF->output_filename($m);
 
-Sets or gets the output filename of the animation.
+It sets or gets the output filename of the animation.
 
 When setting an output filename, make sure you
 specify its extension and it does make sense to FFmpeg (e.g. mp4).
 
+Return value:
+
+=over 4
+
+=item * the current output filename.
+
+=back
 
 =head2 C<input_file_with_images($m)>
 
   $aaFF->input_file_with_images($m) or die "failed";
 
 Reads file C<$m> which must contain filenames, one filename
-per line, and adds the up to the list of input images to make up the
+per line, and adds the up to the list of input images to create the
 animation.
 
-It returns 0 on failure, 1 on success.
+Return value:
+
+=over 4
+
+=item * 0 on failure, 1 on success.
+
+=back
 
 =head2 C<num_input_images()>
 
   my $N = $aaFF->num_input_images();
 
-It returns the number of input images currently
-in the list to make up the animation.
+Return value:
+
+=over 4
+
+=item * on success, it returns the number of input images currently
+in the list to create the animation. On failure, or when there
+are now images to create the animation, it returns 0.
+
+=back
 
 =head2 C<clear_input_images()>
 
   $aaFF->clear_input_images();
 
-It clears the list of input images to make up an animation.
+It clears the list of input images to create an animation.
 Zero, null, it's over for Bojo.
 
 =head2 C<ffmpeg_executable()>
 
   my $ret = $aaFF->ffmpeg_executable();
 
-It returns the path to C<ffmpeg> executable as it was set during construction.
-You can not change the path to the executable mid-stream. Set it via
-the constructor or rely on the installation to detect it
-and hardcode it to the module file.
+You can not change the path to the executable mid-stream.
+
+Return value:
+
+=over 4
+
+=item * on success, it returns the path to C<ffmpeg> executable
+as it was set during module installation.
+The return value will be C<undef> if C<ffmpeg> executable was not
+detected during installation.
+
+=back
 
 =head2 C<verbosity($m)>
 
@@ -655,6 +710,14 @@ and hardcode it to the module file.
 
 It sets or gets the verbosity level. Zero being mute.
 
+Return value:
+
+=over 4
+
+=item * the current verbosity level.
+
+=back
+
 =head2 C<frame_duration($m)>
 
   my $ret = $aaFF->frame_duration($m);
@@ -663,7 +726,13 @@ It sets or gets the frame duration in (fractional) seconds.
 Frame duration is the time that each frame(=image) appears
 in the produced animation.
 
+Return value:
 
+=over 4
+
+=item * the current frame duration in (fractional) seconds.
+
+=back
 =head1 SCRIPTS
 
 A script for making animations from input images using C<ffmpeg>
